@@ -5,7 +5,7 @@ import urllib.request as urllib2
 
 from pyspark.context import SparkContext
 from pyspark.sql import SparkSession
-
+import inspect
 
 class Trompi(object):
 
@@ -22,7 +22,7 @@ class Trompi(object):
     def register_base_directory_path(cls, path):
         cls._base_directory_path = path
     @classmethod
-    def import_(cls, remote_file_path, g, import_member=False):
+    def import_(cls, remote_file_path, g=inspect.stack()[1][0].f_globals, import_member=False):
         file_name = remote_file_path.split("/")[-1]
         _s = file_name.split(".")
         assert _s.__len__() == 2
